#!/usr/bin/env bb

(require  '[babashka.curl :as curl]
          '[babashka.process :as p]
          '[cheshire.core :as json])

(def url "https://api.groq.com/openai/v1/chat/completions")

(def system-msg "
You are an expert programmer that values clear, unambiguous communication and are specialized in generating concise and informative git commit messages. 
Your task is to generate a concise, informative git commit message based on the following git diff.
Be sure that the commit message reflects the entire diff.
It is very important that the entire commit is clear and understandable.
Only reply with the commit message and nothing else.
")

(def diff (:out (p/check (p/sh "git" "diff" "--cached"))))

(def message (json/generate-string
              {:messages [{:role "system" :content system-msg}
                          {:role "user"   :content diff}]
               :model "llama-3.1-70b-versatile"
               :temperature 1
               :max_tokens 1024
               :top_p 1
               :stream false
               :stop nil}))

(def response
  (curl/post url
             {:headers {"Content-Type" "application/json"
                        "Authorization" (str "Bearer " (System/getenv "GROQ_API_KEY"))}
              :body message}))

(def content (get-in (:choices (json/parse-string (:body response) true)) [0 :message :content]))

(println content)
